The classical-quantum combiner (CQC) interface is an interface between higher layers and hardware in a Quantum Internet. It comes with a Python, C and Rust library for constructing CQC messages. The Python library is definitely the best place to get started.

Documentation of CQC can be found at https://softwarequtech.github.io/SimulaQron/html/CQCInterface.html

The CQC can be used to either program hardware which supports the interface or the simulator [https://github.com/SoftwareQuTech/SimulaQron](SimulaQron).

More information about CQC can also be found in the paper on SimulaQron at https://arxiv.org/abs/1712.08032
